# `BioClients.reactome`

## Reactome

Client for Reactome REST API.

* <https://reactome.org/ContentService/>

From [Reactome Data Model](https://reactome.org/documentation/data-model):

  Life on the cellular level is a network of molecular interactions. Molecules
  are synthesized and degraded, undergo a bewildering array of temporary and
  permanent modifications, are transported from one location to another, and
  form complexes with other molecules. Reactome represents all of this
  complexity as reactions in which input physical entities are converted to
  output entities.

  PhysicalEntities include individual molecules, multi-molecular complexes, and
  sets of molecules or complexes grouped together on the basis of shared
  characteristics. Molecules are further classified as genome encoded (DNA,
  RNA, and proteins) or not (all others). Attributes of a PhysicalEntity
  instance capture the chemical structure of an entity, including any covalent
  modifications in the case of a macromolecule, and its subcellular
  localization.
